@@ -63,7 +63,7 @@ report.data.frame <- function(x,
     x <- x[, vapply(x, Negate(inherits), what = "list", FUN.VALUE = TRUE)]
   }
 
-  table <-
+  result_table <-
     report_table(
       x,
       n = n,
@@ -78,7 +78,7 @@ report.data.frame <- function(x,
       ...
     )
 
-  text <-
+  result_text <-
     report_text(
       x,
       n = n,
@@ -93,7 +93,7 @@ report.data.frame <- function(x,
       ...
     )
 
-  as.report(text, table = table, ...)
+  as.report(result_text, table = result_table, ...)
 }
 
 
@@ -113,12 +113,12 @@ report_table.data.frame <- function(x,
                                     missing_percentage = "auto",
                                     ...) {
   table_full <- data.frame()
-  table <- data.frame()
+  result_table <- data.frame()
 
   for (i in seq_len(ncol(x))) {
-    col <- names(x)[i]
+    var_name <- names(x)[i]
     current_table_full <- report_table(
-      x[[col]],
+      x[[var_name]],
       n = n,
       centrality = centrality,
       dispersion = dispersion,
@@ -132,7 +132,7 @@ report_table.data.frame <- function(x,
     )
 
     current_table <- current_table_full
-    current_table$Variable <- col
+    current_table$Variable <- var_name
     current_table$.order <- i
 
     if (nrow(table_full) == 0) {
@@ -142,38 +142,41 @@ report_table.data.frame <- function(x,
     }
 
     current_table <- summary(current_table_full)
-    current_table$Variable <- col
+    current_table$Variable <- var_name
     current_table$.order <- i
 
-    if (nrow(table) == 0) {
-      table <- current_table
+    if (nrow(result_table) == 0) {
+      result_table <- current_table
     } else {
-      table <- merge(table, current_table, all = TRUE)
+      result_table <- merge(result_table, current_table, all = TRUE)
     }
   }
 
-  if ("Level" %in% names(table)) {
-    if ("percentage_Obs" %in% names(table)) {
-      table <- datawizard::data_reorder(table, c("Variable", "Level", "n_Obs", "percentage_Obs"), verbose = FALSE)
+  if ("Level" %in% names(result_table)) {
+    if ("percentage_Obs" %in% names(result_table)) {
+      result_table <- datawizard::data_reorder(
+        result_table, c("Variable", "Level", "n_Obs", "percentage_Obs"),
+        verbose = FALSE
+      )
       table_full <- datawizard::data_reorder(table_full, c("Variable", "Level", "n_Obs", "percentage_Obs"),
         verbose = FALSE
       )
     } else {
-      table <- datawizard::data_reorder(table, c("Variable", "Level", "n_Obs"), verbose = FALSE)
+      result_table <- datawizard::data_reorder(result_table, c("Variable", "Level", "n_Obs"), verbose = FALSE)
       table_full <- datawizard::data_reorder(table_full, c("Variable", "Level", "n_Obs"), verbose = FALSE)
     }
   } else {
-    table <- datawizard::data_reorder(table, c("Variable", "n_Obs"), verbose = FALSE)
+    result_table <- datawizard::data_reorder(result_table, c("Variable", "n_Obs"), verbose = FALSE)
     table_full <- datawizard::data_reorder(table_full, c("Variable", "n_Obs"), verbose = FALSE)
   }
 
   # Reorder cols
-  table <- table[order(table$`.order`), ]
-  table$`.order` <- NULL
-  table_full <- table_full[order(table_full$`.order`), ]
-  table_full$`.order` <- NULL
+  result_table <- result_table[order(result_table$.order), ]
+  result_table$.order <- NULL
+  table_full <- table_full[order(table_full$.order), ]
+  table_full$.order <- NULL
 
-  as.report_table(table_full, summary = table)
+  as.report_table(table_full, summary = result_table)
 }
 
 
@@ -194,7 +197,7 @@ report_parameters.data.frame <- function(x,
                                          missing_percentage = "auto",
                                          ...) {
   text_full <- NULL
-  text <- NULL
+  result_text <- NULL
 
   for (i in seq_len(ncol(x))) {
     r <- report_text(
@@ -213,10 +216,10 @@ report_parameters.data.frame <- function(x,
     )
 
     text_full <- c(text_full, r)
-    text <- c(text, summary(r))
+    result_text <- c(result_text, summary(r))
   }
 
-  as.report_parameters(text_full, summary = text, ...)
+  as.report_parameters(text_full, summary = result_text, ...)
 }
 
 
@@ -256,14 +259,14 @@ report_text.data.frame <- function(x,
     ncol(x), " variables:\n\n",
     as.character(params)
   )
-  text <- paste0(
+  result_text <- paste0(
     "The data contains ",
     nrow(x), " observations of the following ",
     ncol(x), " variables:\n\n",
     as.character(summary(params))
   )
 
-  as.report_text(text_full, summary = text)
+  as.report_text(text_full, summary = result_text)
 }
 
 
@@ -284,7 +287,7 @@ report_statistics.data.frame <- function(x,
                                          missing_percentage = "auto",
                                          ...) {
   text_full <- NULL
-  text <- NULL
+  result_text <- NULL
 
   for (i in seq_len(ncol(x))) {
     r <- report_statistics(
@@ -303,10 +306,10 @@ report_statistics.data.frame <- function(x,
     )
 
     text_full <- c(text_full, r)
-    text <- c(text, summary(r))
+    result_text <- c(result_text, summary(r))
   }
 
-  as.report_statistics(text_full, summary = text)
+  as.report_statistics(text_full, summary = result_text)
 }
 
 
@@ -353,13 +356,13 @@ report_table.grouped_df <- function(x,
   out <- .report_grouped_dataframe(x)
 
   table_full <- data.frame()
-  table <- data.frame()
+  result_table <- data.frame()
 
   for (group in names(out$dfs)) {
-    data <- out$dfs[[group]]
+    group_data <- out$dfs[[group]]
 
     current_table_full <- report_table(
-      data,
+      group_data,
       n = n,
       centrality = centrality,
       dispersion = dispersion,
@@ -373,7 +376,7 @@ report_table.grouped_df <- function(x,
     )
 
     current_table_full$Group <- group
-    if (!length(table_full) == 0) {
+    if (length(table_full) != 0) {
       table_full <- merge(table_full, current_table_full, all = TRUE, sort = FALSE)
     } else {
       table_full <- current_table_full
@@ -381,17 +384,17 @@ report_table.grouped_df <- function(x,
 
     current_table <- summary(current_table_full)
     current_table$Group <- group
-    if (!length(table) == 0) {
-      table <- merge(table, current_table, all = TRUE, sort = FALSE)
+    if (length(result_table) != 0) {
+      result_table <- merge(result_table, current_table, all = TRUE, sort = FALSE)
     } else {
-      table <- current_table
+      result_table <- current_table
     }
   }
 
-  table <- datawizard::data_reorder(table, "Group")
+  result_table <- datawizard::data_reorder(result_table, "Group")
   table_full <- datawizard::data_reorder(table_full, "Group")
 
-  as.report_table(table_full, summary = table)
+  as.report_table(table_full, summary = result_table)
 }
 
 
@@ -414,10 +417,10 @@ report_parameters.grouped_df <- function(x,
   params <- NULL
 
   for (group in names(out$dfs)) {
-    data <- out$dfs[[group]]
+    group_data <- out$dfs[[group]]
 
     r <- report_parameters(
-      data,
+      group_data,
       n = n,
       centrality = centrality,
       dispersion = dispersion,
@@ -454,13 +457,13 @@ report_text.grouped_df <- function(x,
   out <- .report_grouped_dataframe(x)
 
   text_full <- out$intro
-  text <- out$intro
+  result_text <- out$intro
 
   for (group in names(out$dfs)) {
-    data <- out$dfs[[group]]
+    group_data <- out$dfs[[group]]
 
     r <- report_parameters(
-      data,
+      group_data,
       n = n,
       centrality = centrality,
       dispersion = dispersion,
@@ -473,13 +476,13 @@ report_text.grouped_df <- function(x,
       ...
     )
 
-    text_group <- paste0("\n- ", group, " (n = ", nrow(data), "):\n")
+    text_group <- paste0("\n- ", group, " (n = ", nrow(group_data), "):\n")
 
     text_full <- paste0(text_full, "\n", paste0(text_group, as.character(r)))
-    text <- paste0(text, "\n", paste0(text_group, as.character(summary(r))))
+    result_text <- paste0(result_text, "\n", paste0(text_group, as.character(summary(r))))
   }
 
-  as.report_text(text_full, summary = text)
+  as.report_text(text_full, summary = result_text)
 }
 
 #' @export
@@ -502,13 +505,13 @@ report_statistics.grouped_df <- function(x,
   out <- .report_grouped_dataframe(x)
 
   text_full <- NULL
-  text <- NULL
+  result_text <- NULL
 
   for (group in names(out$dfs)) {
-    data <- out$dfs[[group]]
+    group_data <- out$dfs[[group]]
 
     r <- report_statistics(
-      data,
+      group_data,
       n = n,
       centrality = centrality,
       dispersion = dispersion,
@@ -522,10 +525,10 @@ report_statistics.grouped_df <- function(x,
     )
 
     text_full <- c(text_full, paste0(group, ", ", as.character(r)))
-    text <- c(text, paste0(group, ", ", as.character(summary(r))))
+    result_text <- c(result_text, paste0(group, ", ", as.character(summary(r))))
   }
 
-  as.report_statistics(text_full, summary = text)
+  as.report_statistics(text_full, summary = result_text)
 }
 
 
