@@ -4,10 +4,10 @@ report.factor <- function(x, levels_percentage = "auto", ...) {
   if (!is.factor(x)) {
     x <- as.factor(x)
   }
-  table <- report_table(x, levels_percentage = levels_percentage, ...)
-  text <- report_text(x, levels_percentage = levels_percentage, ...)
+  report_table_obj <- report_table(x, levels_percentage = levels_percentage, ...)
+  report_text_obj <- report_text(x, levels_percentage = levels_percentage, ...)
 
-  as.report(text, table = table, ...)
+  as.report(report_text_obj, table = report_table_obj, ...)
 }
 
 #' @export
@@ -37,12 +37,12 @@ report_table.factor <- function(x, levels_percentage = "auto", ...) {
   table_full$percentage_Obs <- table_full$n_Obs / length(x) * 100
 
   # Shorten
-  table <- table_full
+  report_table_obj <- table_full
   if (!levels_percentage) {
-    table <- datawizard::data_remove(table, "percentage_Obs")
+    report_table_obj <- datawizard::data_remove(report_table_obj, "percentage_Obs")
   }
 
-  as.report_table(table_full, summary = table)
+  as.report_table(table_full, summary = report_table_obj)
 }
 
 #' @export
@@ -76,18 +76,18 @@ report_parameters.factor <- function(x, table = NULL, levels_percentage = "auto"
   )
 
   if (isTRUE(levels_percentage)) {
-    text <- paste0(
+    report_text_obj <- paste0(
       text_levels, " (",
       text_percentage_Obs, ")"
     )
   } else {
-    text <- paste0(
+    report_text_obj <- paste0(
       text_levels, " (",
       text_n_Obs, ")"
     )
   }
 
-  as.report_parameters(text_full, summary = text, ...)
+  as.report_parameters(text_full, summary = report_text_obj, ...)
 }
 
 #' @export
@@ -126,9 +126,9 @@ report_text.factor <- function(x, table = NULL, levels_percentage = "auto", ...)
   }
 
   text_full <- paste0(text_total_levels, datawizard::text_concatenate(params, sep = ", "))
-  text <- paste0(text_total_levels, datawizard::text_concatenate(summary(params), sep = ", "))
+  report_text_obj <- paste0(text_total_levels, datawizard::text_concatenate(summary(params), sep = ", "))
 
-  as.report_text(text_full, summary = text)
+  as.report_text(text_full, summary = report_text_obj)
 }
 
 #' @export
@@ -161,18 +161,18 @@ report_statistics.factor <- function(x, table = NULL, levels_percentage = "auto"
   )
 
   if (isTRUE(levels_percentage)) {
-    text <- paste0(
+    report_text_obj <- paste0(
       text_levels, ", ",
       text_percentage_Obs
     )
   } else {
-    text <- paste0(
+    report_text_obj <- paste0(
       text_levels, ", ",
       text_n_Obs
     )
   }
 
-  as.report_statistics(paste(text_full, collapse = "; "), summary = paste(text, collapse = "; "))
+  as.report_statistics(paste(text_full, collapse = "; "), summary = paste(report_text_obj, collapse = "; "))
 }
 
 #' @export
