@@ -24,7 +24,7 @@ report.numeric <- function(x,
     ), call. = FALSE)
   }
 
-  table <- report_table(
+  numeric_table <- report_table(
     x,
     centrality = centrality,
     dispersion = dispersion,
@@ -35,9 +35,9 @@ report.numeric <- function(x,
     ...
   )
 
-  text <- report_text(
+  result_text <- report_text(
     x,
-    table = table,
+    table = numeric_table,
     centrality = centrality,
     dispersion = dispersion,
     range = range,
@@ -47,7 +47,7 @@ report.numeric <- function(x,
     ...
   )
 
-  as.report(text, table = table, ...)
+  as.report(result_text, table = numeric_table, ...)
 }
 
 
@@ -68,7 +68,7 @@ report_table.numeric <- function(x,
   table_full <- data.frame(
     Mean = mean(x, na.rm = TRUE),
     SD = stats::sd(x, na.rm = TRUE),
-    Median = stats::median(x),
+    Median = stats::median(x, na.rm = TRUE),
     MAD = stats::mad(x, na.rm = TRUE),
     Min = min(x, na.rm = TRUE),
     Max = max(x, na.rm = TRUE),
@@ -81,53 +81,49 @@ report_table.numeric <- function(x,
   table_full$percentage_Missing <- table_full$n_Missing / table_full$n_Obs * 100
 
   # Summary table
-  table <- table_full
+  summary_table <- table_full
 
   # N observations
-  if (isFALSE(n)) table$n_Obs <- NULL
+  if (isFALSE(n)) summary_table$n_Obs <- NULL
 
   # Centrality and dispersion
   if (!isFALSE(centrality) && !is.null(centrality)) {
     if (centrality == "median") {
       if (dispersion) {
-        table <- datawizard::data_remove(table, c("Mean", "SD"))
+        summary_table <- datawizard::data_remove(summary_table, c("Mean", "SD"))
       } else {
-        table <- datawizard::data_remove(table, c("Mean", "SD", "MAD"))
+        summary_table <- datawizard::data_remove(summary_table, c("Mean", "SD", "MAD"))
       }
+    } else if (dispersion) {
+      summary_table <- datawizard::data_remove(summary_table, c("Median", "MAD"))
     } else {
-      if (dispersion) {
-        table <- datawizard::data_remove(table, c("Median", "MAD"))
-      } else {
-        table <- datawizard::data_remove(table, c("Median", "MAD", "SD"))
-      }
+      summary_table <- datawizard::data_remove(summary_table, c("Median", "MAD", "SD"))
     }
   }
 
   # Range
   if (!range) {
-    table <- datawizard::data_remove(table, c("Min", "Max"))
+    summary_table <- datawizard::data_remove(summary_table, c("Min", "Max"))
   }
 
   # Distribution
   if (!distribution) {
-    table <- datawizard::data_remove(table, c("Skewness", "Kurtosis"))
+    summary_table <- datawizard::data_remove(summary_table, c("Skewness", "Kurtosis"))
   }
 
   # Missing
-  if (!is.null(missing_percentage)) {
-    if (isTRUE(missing_percentage)) {
-      table <- datawizard::data_remove(table, "n_Missing")
-      table_full <- datawizard::data_remove(table_full, "n_Missing")
-    } else {
-      table <- datawizard::data_remove(table, "percentage_Missing")
-      table_full <- datawizard::data_remove(table_full, "percentage_Missing")
-    }
-  } else {
-    table <- datawizard::data_remove(table, c("percentage_Missing", "n_Missing"))
+  if (is.null(missing_percentage)) {
+    summary_table <- datawizard::data_remove(summary_table, c("percentage_Missing", "n_Missing"))
     table_full <- datawizard::data_remove(table_full, c("percentage_Missing", "n_Missing"))
+  } else if (isTRUE(missing_percentage)) {
+    summary_table <- datawizard::data_remove(summary_table, "n_Missing")
+    table_full <- datawizard::data_remove(table_full, "n_Missing")
+  } else {
+    summary_table <- datawizard::data_remove(summary_table, "percentage_Missing")
+    table_full <- datawizard::data_remove(table_full, "percentage_Missing")
   }
 
-  as.report_table(table_full, summary = table)
+  as.report_table(table_full, summary = summary_table)
 }
 
 
@@ -184,22 +180,20 @@ report_parameters.numeric <- function(x,
   text_kurtosis <- paste0("Kurtosis = ", insight::format_value(table$Kurtosis[1]))
 
   # Missing
-  if (!is.null(missing_percentage)) {
-    if (isTRUE(missing_percentage)) {
-      n_missing <- table$percentage_Missing[1]
-      text_missing <- paste0(
-        insight::format_value(table$percentage_Missing[1],
-          protect_integers = TRUE,
-          digits = digits
-        ),
-        "% missing"
-      )
-    } else {
-      n_missing <- table$n_Missing[1]
-      text_missing <- paste0(table$n_Missing[1], " missing")
-    }
-  } else {
+  if (is.null(missing_percentage)) {
     text_missing <- NULL
+  } else if (isTRUE(missing_percentage)) {
+    n_missing <- table$percentage_Missing[1]
+    text_missing <- paste0(
+      insight::format_value(table$percentage_Missing[1],
+        protect_integers = TRUE,
+        digits = digits
+      ),
+      "% missing"
+    )
+  } else {
+    n_missing <- table$n_Missing[1]
+    text_missing <- paste0(table$n_Missing[1], " missing")
   }
 
   text_full <- c(
@@ -215,43 +209,43 @@ report_parameters.numeric <- function(x,
   )
 
   # Shorten ---
-  text <- text_full
+  result_text <- text_full
 
   # N observations
-  if (isFALSE(n)) text <- text[!names(text) %in% "n_Obs"]
+  if (isFALSE(n)) result_text <- result_text[names(result_text) != "n_Obs"]
 
   # Centrality and dispersion
   if (!isFALSE(centrality) && !is.null(centrality)) {
     if (centrality == "median") {
-      text <- text[!names(text) %in% c("Mean", "Dispersion_Mean")]
+      result_text <- result_text[!names(result_text) %in% c("Mean", "Dispersion_Mean")]
       if (!dispersion) {
-        text <- text[!names(text) %in% "Dispersion_Median"]
+        result_text <- result_text[names(result_text) != "Dispersion_Median"]
       }
     } else {
-      text <- text[!names(text) %in% c("Median", "Dispersion_Median")]
+      result_text <- result_text[!names(result_text) %in% c("Median", "Dispersion_Median")]
       if (!dispersion) {
-        text <- text[!names(text) %in% "Dispersion_Mean"]
+        result_text <- result_text[names(result_text) != "Dispersion_Mean"]
       }
     }
   } else {
-    text <- text[!names(text) %in% c("Mean", "Dispersion_Mean", "Median", "Dispersion_Median")]
+    result_text <- result_text[!names(result_text) %in% c("Mean", "Dispersion_Mean", "Median", "Dispersion_Median")]
   }
 
   # Range
   if (!range) {
-    text <- text[!names(text) %in% "Range"]
+    result_text <- result_text[names(result_text) != "Range"]
   }
 
   # Distribution
   if (!distribution) {
-    text <- text[!names(text) %in% c("Skewness", "Kurtosis")]
+    result_text <- result_text[!names(result_text) %in% c("Skewness", "Kurtosis")]
   }
 
   if (is.null(missing_percentage) || n_missing == 0) {
-    text <- text[!names(text) %in% "Missing"]
+    result_text <- result_text[names(result_text) != "Missing"]
   }
 
-  as.report_parameters(text_full, summary = text, ...)
+  as.report_parameters(text_full, summary = result_text, ...)
 }
 
 
@@ -290,7 +284,7 @@ report_text.numeric <- function(x,
     ...
   )
 
-  text <- paste0(
+  result_text <- paste0(
     name,
     ": ",
     toString(params)
@@ -302,7 +296,7 @@ report_text.numeric <- function(x,
     toString(summary(params))
   )
 
-  as.report_text(text, summary = short)
+  as.report_text(result_text, summary = short)
 }
 
 
@@ -334,8 +328,8 @@ report_statistics.numeric <- function(x,
     ...
   )
 
-  text <- toString(params)
+  result_text <- toString(params)
   short <- toString(summary(params))
 
-  as.report_statistics(text, summary = short)
+  as.report_statistics(result_text, summary = short)
 }
