@@ -21,10 +21,10 @@
 #' @include report.lm.R report.lme4.R
 #' @export
 report.stanreg <- function(x, ...) {
-  table <- report_table(x, include_effectsize = FALSE, ...)
-  text <- report_text(x, table = table, ...)
+  stanreg_table <- report_table(x, include_effectsize = FALSE, ...)
+  report_text_result <- report_text(x, table = stanreg_table, ...)
 
-  as.report(text, table = table, ...)
+  as.report(report_text_result, table = stanreg_table, ...)
 }
 
 #' @export
@@ -84,13 +84,13 @@ report_priors.stanreg <- function(x, ...) {
   values <- paste0(params$Prior_Distribution, " (", values, ")")
 
   if (length(unique(values)) == 1 && nrow(params) > 1) {
-    text <- paste0("all set as ", values[1])
+    priors_text <- paste0("all set as ", values[1])
   } else {
-    text <- paste0("set as ", values)
+    priors_text <- paste0("set as ", values)
   }
 
-  text <- paste0("Priors over parameters were ", text, " distributions")
-  as.report_priors(text)
+  priors_text <- paste0("Priors over parameters were ", priors_text, " distributions")
+  as.report_priors(priors_text)
 }
 
 
@@ -103,45 +103,45 @@ report_parameters.stanreg <- function(x,
                                       include_diagnostic = TRUE,
                                       ...) {
   # Get data
-  data <- bayestestR::sexit(x, ...)
+  sexit_data <- bayestestR::sexit(x, ...)
 
-  att <- attributes(data)
+  att <- attributes(sexit_data)
   info <- paste0(att$sexit_info, " ", att$sexit_thresholds)
 
-  params <- as.data.frame(data)
+  params <- as.data.frame(sexit_data)
 
   # Parameters' names
-  text <- .parameters_starting_text(x, params)
+  param_text <- .parameters_starting_text(x, params)
 
   # Replace parameters names
-  for (i in seq_along(text)) {
-    att$sexit_textlong[i] <- gsub(names(text)[i], text[i], att$sexit_textlong[i], fixed = TRUE)
-    att$sexit_textshort[i] <- gsub(names(text)[i], text[i], att$sexit_textshort[i], fixed = TRUE)
+  for (i in seq_along(param_text)) {
+    att$sexit_textlong[i] <- gsub(names(param_text)[i], param_text[i], att$sexit_textlong[i], fixed = TRUE)
+    att$sexit_textshort[i] <- gsub(names(param_text)[i], param_text[i], att$sexit_textshort[i], fixed = TRUE)
   }
 
   # Include intercept
   if (isFALSE(include_intercept)) {
-    idx <- !params$Parameter == "(Intercept)"
+    idx <- params$Parameter != "(Intercept)"
   } else {
     idx <- rep(TRUE, nrow(params))
   }
 
-  text <- att$sexit_textshort[idx]
-  text_full <- att$sexit_textlong[idx]
+  param_text <- att$sexit_textshort[idx]
+  param_text_full <- att$sexit_textlong[idx]
 
   # remove NAs...
-  text <- text[!is.na(text)]
-  text_full <- text_full[!is.na(text_full)]
+  param_text <- param_text[!is.na(param_text)]
+  param_text_full <- param_text_full[!is.na(param_text_full)]
 
   # Diagnostic or Convergence
   if (include_diagnostic) {
     diagnostic <- bayestestR::diagnostic_posterior(x, ...)
 
     param.dgn <- .parameters_diagnostic_bayesian(diagnostic, only_when_insufficient = TRUE)[idx]
-    text <- datawizard::text_paste(text, param.dgn, sep = ". ")
+    param_text <- datawizard::text_paste(param_text, param.dgn, sep = ". ")
 
     param.dgn <- .parameters_diagnostic_bayesian(diagnostic, only_when_insufficient = FALSE)[idx]
-    text_full <- datawizard::text_paste(text_full, param.dgn, sep = ". ")
+    param_text_full <- datawizard::text_paste(param_text_full, param.dgn, sep = ". ")
 
     info <- paste(
       info,
@@ -151,7 +151,7 @@ report_parameters.stanreg <- function(x,
     )
   }
 
-  as.report_parameters(text_full, summary = text, parameters = data, info = info, ...)
+  as.report_parameters(param_text_full, summary = param_text, parameters = sexit_data, info = info, ...)
 }
 
 
@@ -162,30 +162,30 @@ report_parameters.stanreg <- function(x,
 report_intercept.stanreg <- function(x, ...) {
   posteriors <- insight::get_parameters(x)
 
-  if ("(Intercept)" %in% names(posteriors)) {
-    intercept <- posteriors[["(Intercept)"]]
-  } else {
+  if (!("(Intercept)" %in% names(posteriors))) {
     return(as.report_intercept("", summary = "", ...))
   }
 
-  data <- bayestestR::sexit(intercept, ...)
+  intercept <- posteriors[["(Intercept)"]]
+
+  intercept_data <- bayestestR::sexit(intercept, ...)
 
   endtext <- paste0(
     " is at ",
-    insight::format_value(data$Median),
+    insight::format_value(intercept_data$Median),
     " (",
-    insight::format_ci(data$CI_low, data$CI_high, ci = data$CI),
+    insight::format_ci(intercept_data$CI_low, intercept_data$CI_high, ci = intercept_data$CI),
     ")."
   )
 
-  text <- paste0("The model's intercept", endtext)
-  text_full <- paste0(
+  intercept_text <- paste0("The model's intercept", endtext)
+  intercept_text_full <- paste0(
     "The model's intercept",
     .find_intercept(x),
     endtext
   )
 
-  as.report_intercept(text_full, summary = text, ...)
+  as.report_intercept(intercept_text_full, summary = intercept_text, ...)
 }
 
 
@@ -197,7 +197,7 @@ report_info.stanreg <- function(x, parameters = NULL, ...) {
     parameters <- report_parameters(x, ...)
   }
 
-  text <- attributes(parameters)$info
+  info_text <- attributes(parameters)$info
 
-  as.report_info(text)
+  as.report_info(info_text)
 }
