@@ -1,30 +1,30 @@
 #' @keywords internal
 .combine_tables_effectsize <- function(parameters, effsize) {
   effsize_table <- attributes(effsize)$table
-  table <- merge(parameters, effsize_table, sort = FALSE, all = TRUE)
-  # table <- table[order(
-  #   match(table$Parameter, parameters$Parameter)), ]
-  row.names(table) <- NULL
+  combined_table <- merge(parameters, effsize_table, sort = FALSE, all = TRUE)
+  # combined_table <- combined_table[order(
+  #   match(combined_table$Parameter, parameters$Parameter)), ]
+  row.names(combined_table) <- NULL
 
   # Prepare output
-  class(table) <- class(parameters)
-  attributes(table) <- utils::modifyList(attributes(parameters), attributes(table))
+  class(combined_table) <- class(parameters)
+  attributes(combined_table) <- utils::modifyList(attributes(parameters), attributes(combined_table))
 
-  table
+  combined_table
 }
 
 
 #' @keywords internal
 .combine_tables_performance <- function(parameters, performance) {
-  table <- parameters
+  combined_table <- parameters
 
   # Pretty names
   if (!is.null(attributes(parameters)$pretty_names)) {
-    table$Parameter <- attributes(parameters)$pretty_names[parameters$Parameter]
+    combined_table$Parameter <- attributes(parameters)$pretty_names[parameters$Parameter]
   }
 
   # Skip row
-  table[nrow(table) + 1, ] <- NA
+  combined_table[nrow(combined_table) + 1, ] <- NA
 
   # Prettify performance names
   perf_names <- colnames(performance)
@@ -50,27 +50,29 @@
   names(perf_vertical)[1] <- name_parameter
 
   # Merge
-  table <- merge(table, perf_vertical, by = name_parameter, all = TRUE, sort = FALSE)
+  combined_table <- merge(combined_table, perf_vertical, by = name_parameter, all = TRUE, sort = FALSE)
 
   # Prepare output
-  class(table) <- class(parameters)
-  attributes(table) <- utils::modifyList(attributes(parameters), attributes(table))
+  class(combined_table) <- class(parameters)
+  attributes(combined_table) <- utils::modifyList(attributes(parameters), attributes(combined_table))
 
   # Add pretty names
-  pretty_names <- table$Parameter
+  pretty_names <- combined_table$Parameter
   # pretty_names <- pretty_names[!is.na(pretty_names)]
   names(pretty_names) <- pretty_names
-  attr(table, "pretty_names") <- pretty_names
+  attr(combined_table, "pretty_names") <- pretty_names
 
-  table
+  combined_table
 }
 
 
 #' @keywords internal
 .remove_performance <- function(table) {
   if ("Fit" %in% names(table)) {
-    table <- table[is.na(table$Fit), ]
-    table <- table[!is.na(table$Parameter), ]
+    params_table <- table[is.na(table$Fit), ]
+    params_table <- params_table[!is.na(params_table$Parameter), ]
+  } else {
+    params_table <- table
   }
-  table
+  params_table
 }
